@@ -16,10 +16,9 @@
 #include <qstrlist.h>
 #include <qgroupbox.h>
 #include <qradiobutton.h>
-#include <kspinbox.h>
 #include <qbuttongroup.h>
 #include <qlabel.h>
-#include <ktablistbox.h>
+//#include <ktablistbox.h>
 
 class leasesDialog : public QDialog
 {
@@ -40,7 +39,7 @@ protected:
     void update();
     QLabel *label, *ed1, *ed2, *ed3, *ed4;
     QLabel *p1, *p2, *p3, *p4, *p5, *p6;
-    KTabListBox *leasesListBox;
+    QListView *leasesListBox;
     QGroupBox *LeasesBox;
     QPushButton *Update_Button, *Exit_Button;
 };
