@@ -8,7 +8,7 @@
 #include "scopeDialog.moc"
 #include "advancedDialog.h"
 #include <qlayout.h>
-
+#include <klocale.h>
 
 scopeDialog::scopeDialog (scopeAddresses *sa,QWidget* parent, const char* name) 
                         : QDialog ( parent, name, TRUE, 634880 )
@@ -48,7 +48,7 @@ scopeDialog::scopeDialog (scopeAddresses *sa,QWidget* parent, const char* name)
   connect( Advanced_Button, SIGNAL(clicked()), SLOT(Advanced_Click()) );
   buttonLayout->addWidget(Advanced_Button);
 
-  Ok_Button = new QPushButton(i18n("Ok"), this);
+  Ok_Button = new QPushButton(i18n("OK"), this);
   Ok_Button->setMinimumSize(Ok_Button->sizeHint());
   connect( Ok_Button, SIGNAL(clicked()), SLOT(OK_Click()) );
   buttonLayout->addWidget(Ok_Button);
@@ -61,6 +61,7 @@ scopeDialog::scopeDialog (scopeAddresses *sa,QWidget* parent, const char* name)
   Subnet_Label = new QLabel(i18n("Subnet:"), IP_poolBox);
   Mask_Label = new QLabel(i18n("Subnet Mask:"), IP_poolBox);
   Routers_Label = new QLabel(i18n("Routers:"), IP_poolBox);
+  Broadcast_Label = new QLabel(i18n("Broadcast:"), IP_poolBox);
   DomainName_Label = new QLabel(i18n("Domain Name:"), IP_poolBox);
   NameServers_Label = new QLabel(i18n("Name Servers:"), IP_poolBox);
   NetbiosNameServers_Label = new QLabel(i18n("Wins Servers:"), IP_poolBox);
@@ -94,50 +95,51 @@ scopeDialog::scopeDialog (scopeAddresses *sa,QWidget* parent, const char* name)
   Subnet_Label->setGeometry(10,20,widthSize,Subnet_Label->sizeHint().height());
   Mask_Label->setGeometry(10,45,widthSize,Mask_Label->sizeHint().height());
   Routers_Label->setGeometry(10,70,widthSize,Routers_Label->sizeHint().height());
-  DomainName_Label->setGeometry(10,95,domainSize,DomainName_Label->sizeHint().height());
-  NameServers_Label->setGeometry(10,120,domainSize,NameServers_Label->sizeHint().height());
-  NetbiosNameServers_Label->setGeometry(10,145,domainSize,NetbiosNameServers_Label->sizeHint().height());
-  Range_Label->setGeometry(10,170,Range_Label->sizeHint().width(),Range_Label->sizeHint().height());
-  Ex_Start_IP_Label->setGeometry(10,190,widthSize,Ex_Start_IP_Label->sizeHint().height());
-  Ex_End_IP_Label->setGeometry(10,210,widthSize,Ex_End_IP_Label->sizeHint().height());
+  Broadcast_Label->setGeometry(10,95,widthSize,Routers_Label->sizeHint().height());
+  DomainName_Label->setGeometry(10,120,domainSize,DomainName_Label->sizeHint().height());
+  NameServers_Label->setGeometry(10,145,domainSize,NameServers_Label->sizeHint().height());
+  NetbiosNameServers_Label->setGeometry(10,170,domainSize,NetbiosNameServers_Label->sizeHint().height());
+  Range_Label->setGeometry(10,195,Range_Label->sizeHint().width(),Range_Label->sizeHint().height());
+  Ex_Start_IP_Label->setGeometry(10,220,widthSize,Ex_Start_IP_Label->sizeHint().height());
+  Ex_End_IP_Label->setGeometry(10,245,widthSize,Ex_End_IP_Label->sizeHint().height());
 
   Subnet_Edit1 = new QLineEdit(IP_poolBox);
-  Subnet_Edit1->setGeometry((widthSize+20), 20,25, 20 );
+  Subnet_Edit1->setGeometry((widthSize+20), 20,27, 20 );
   Subnet_Edit1->setFont( font );
   Subnet_Edit1->setMaxLength(3);
 
   Subnet_Edit2 = new QLineEdit(IP_poolBox);
-  Subnet_Edit2->setGeometry((widthSize+46), 20,25, 20 );
+  Subnet_Edit2->setGeometry((widthSize+48), 20,27, 20 );
   Subnet_Edit2->setFont( font );
   Subnet_Edit2->setMaxLength(3);
 
   Subnet_Edit3 = new QLineEdit(IP_poolBox);
-  Subnet_Edit3->setGeometry((widthSize+72), 20,25, 20 );
+  Subnet_Edit3->setGeometry((widthSize+76), 20,27, 20 );
   Subnet_Edit3->setFont( font );
   Subnet_Edit3->setMaxLength(3);
 
   Subnet_Edit4 = new QLineEdit(IP_poolBox);
-  Subnet_Edit4->setGeometry((widthSize+98), 20,25, 20 );
+  Subnet_Edit4->setGeometry((widthSize+104), 20,27, 20 );
   Subnet_Edit4->setFont( font );
   Subnet_Edit4->setMaxLength(3);
 
   Mask_Edit1 = new QLineEdit(IP_poolBox);
-  Mask_Edit1->setGeometry((widthSize+20), 45,25, 20 );
+  Mask_Edit1->setGeometry((widthSize+20), 45,27, 20 );
   Mask_Edit1->setFont( font );
   Mask_Edit1->setMaxLength(3);
 
   Mask_Edit2 = new QLineEdit(IP_poolBox);
-  Mask_Edit2->setGeometry((widthSize+46), 45,25, 20 );
+  Mask_Edit2->setGeometry((widthSize+48), 45,27, 20 );
   Mask_Edit2->setFont( font );
   Mask_Edit2->setMaxLength(3);
 
   Mask_Edit3 = new QLineEdit(IP_poolBox);
-  Mask_Edit3->setGeometry((widthSize+72), 45,25, 20 );
+  Mask_Edit3->setGeometry((widthSize+76), 45,27, 20 );
   Mask_Edit3->setFont( font );
   Mask_Edit3->setMaxLength(3);
 
   Mask_Edit4 = new QLineEdit(IP_poolBox);
-  Mask_Edit4->setGeometry((widthSize+98), 45,25, 20 );
+  Mask_Edit4->setGeometry((widthSize+104), 45,27, 20 );
   Mask_Edit4->setFont( font );
   Mask_Edit4->setMaxLength(3);
   
@@ -145,75 +147,79 @@ scopeDialog::scopeDialog (scopeAddresses *sa,QWidget* parent, const char* name)
   Routers_Edit->setGeometry((domainSize+20), 70,((widthSize+buttonSize+150)-(domainSize+40)), 20);
   Routers_Edit->setFont( font );
 
+  Broadcast_Edit = new QLineEdit(IP_poolBox);
+  Broadcast_Edit->setGeometry((domainSize+20), 95,((widthSize+buttonSize+150)-(domainSize+40)), 20);
+  Broadcast_Edit->setFont( font );
+
   DomainName_Edit = new QLineEdit(IP_poolBox);
-  DomainName_Edit->setGeometry((domainSize+20), 95,((widthSize+buttonSize+150)-(domainSize+40)), 20 );
+  DomainName_Edit->setGeometry((domainSize+20), 120,((widthSize+buttonSize+150)-(domainSize+40)), 20 );
   DomainName_Edit->setFont( font );
 
   NameServers_Edit = new QLineEdit(IP_poolBox);
-  NameServers_Edit->setGeometry((domainSize+20), 120,((widthSize+buttonSize+150)-(domainSize+40)), 20 );
+  NameServers_Edit->setGeometry((domainSize+20), 145,((widthSize+buttonSize+150)-(domainSize+40)), 20 );
   NameServers_Edit->setFont( font );
 
   NetbiosNameServers_Edit = new QLineEdit(IP_poolBox);
-  NetbiosNameServers_Edit->setGeometry((domainSize+20), 145,((widthSize+buttonSize+150)-(domainSize+40)), 20 );
+  NetbiosNameServers_Edit->setGeometry((domainSize+20), 170,((widthSize+buttonSize+150)-(domainSize+40)), 20 );
   NetbiosNameServers_Edit->setFont( font );
 
   Ex_Start_IP_Edit1 = new QLineEdit(IP_poolBox);
-  Ex_Start_IP_Edit1->setGeometry((widthSize+20), 190,25, 20 );
+  Ex_Start_IP_Edit1->setGeometry((widthSize+20), 220,27, 20 );
   Ex_Start_IP_Edit1->setFont( font );
   Ex_Start_IP_Edit1->setMaxLength(3);
 
   Ex_Start_IP_Edit2 = new QLineEdit(IP_poolBox);
-  Ex_Start_IP_Edit2->setGeometry((widthSize+46), 190,25, 20 );
+  Ex_Start_IP_Edit2->setGeometry((widthSize+48), 220,27, 20 );
   Ex_Start_IP_Edit2->setFont( font );
   Ex_Start_IP_Edit2->setMaxLength(3);
 
   Ex_Start_IP_Edit3 = new QLineEdit(IP_poolBox);
-  Ex_Start_IP_Edit3->setGeometry((widthSize+72), 190,25, 20 );
+  Ex_Start_IP_Edit3->setGeometry((widthSize+76), 220,27, 20 );
   Ex_Start_IP_Edit3->setFont( font );
   Ex_Start_IP_Edit3->setMaxLength(3);
 
   Ex_Start_IP_Edit4 = new QLineEdit(IP_poolBox);
-  Ex_Start_IP_Edit4->setGeometry((widthSize+98), 190,25, 20 );
+  Ex_Start_IP_Edit4->setGeometry((widthSize+104), 220,27, 20 );
   Ex_Start_IP_Edit4->setFont( font );
   Ex_Start_IP_Edit4->setMaxLength(3);
 
   Ex_End_IP_Edit1 = new QLineEdit(IP_poolBox);
-  Ex_End_IP_Edit1->setGeometry((widthSize+20), 210,25, 20 );
+  Ex_End_IP_Edit1->setGeometry((widthSize+20), 245,27, 20 );
   Ex_End_IP_Edit1->setFont( font );
   Ex_End_IP_Edit1->setMaxLength(3);
 
   Ex_End_IP_Edit2 = new QLineEdit(IP_poolBox);
-  Ex_End_IP_Edit2->setGeometry((widthSize+46), 210,25, 20 );
+  Ex_End_IP_Edit2->setGeometry((widthSize+48), 245,27, 20 );
   Ex_End_IP_Edit2->setFont( font );
   Ex_End_IP_Edit2->setMaxLength(3);
 
   Ex_End_IP_Edit3 = new QLineEdit(IP_poolBox);
-  Ex_End_IP_Edit3->setGeometry((widthSize+72), 210,25, 20 );
+  Ex_End_IP_Edit3->setGeometry((widthSize+76), 245,27, 20 );
   Ex_End_IP_Edit3->setFont( font );
   Ex_End_IP_Edit3->setMaxLength(3);
 
   Ex_End_IP_Edit4 = new QLineEdit(IP_poolBox);
-  Ex_End_IP_Edit4->setGeometry((widthSize+98), 210,25, 20 );
+  Ex_End_IP_Edit4->setGeometry((widthSize+104), 245,27, 20 );
   Ex_End_IP_Edit4->setFont( font );
   Ex_End_IP_Edit4->setMaxLength(3);
   
-  connect( Subnet_Edit1, SIGNAL(textChanged(const char*)), SLOT(Subnet_change1(const char*)));
-  connect( Subnet_Edit2, SIGNAL(textChanged(const char*)), SLOT(Subnet_change2(const char*)));
-  connect( Subnet_Edit3, SIGNAL(textChanged(const char*)), SLOT(Subnet_change3(const char*)));
-  connect( Subnet_Edit4, SIGNAL(textChanged(const char*)), SLOT(Subnet_change4(const char*)));
-  connect( Ex_Start_IP_Edit1, SIGNAL(textChanged(const char*)), SLOT(Ex_Start_IP_change1(const char*)));
-  connect( Ex_Start_IP_Edit2, SIGNAL(textChanged(const char*)), SLOT(Ex_Start_IP_change2(const char*)));
-  connect( Ex_Start_IP_Edit3, SIGNAL(textChanged(const char*)), SLOT(Ex_Start_IP_change3(const char*)));
-  connect( Ex_Start_IP_Edit4, SIGNAL(textChanged(const char*)), SLOT(Ex_Start_IP_change4(const char*)));
-  connect( Ex_End_IP_Edit1, SIGNAL(textChanged(const char*)), SLOT(Ex_End_IP_change1(const char*)));
-  connect( Ex_End_IP_Edit2, SIGNAL(textChanged(const char*)), SLOT(Ex_End_IP_change2(const char*)));
-  connect( Ex_End_IP_Edit3, SIGNAL(textChanged(const char*)), SLOT(Ex_End_IP_change3(const char*)));
-  connect( Ex_End_IP_Edit4, SIGNAL(textChanged(const char*)), SLOT(Ex_End_IP_change4(const char*)));
+  connect( Subnet_Edit1, SIGNAL(textChanged(const QString&)), SLOT(Subnet_change1(const QString&)));
+  connect( Subnet_Edit2, SIGNAL(textChanged(const QString&)), SLOT(Subnet_change2(const QString&)));
+  connect( Subnet_Edit3, SIGNAL(textChanged(const QString&)), SLOT(Subnet_change3(const QString&)));
+  connect( Subnet_Edit4, SIGNAL(textChanged(const QString&)), SLOT(Subnet_change4(const QString&)));
+  connect( Ex_Start_IP_Edit1, SIGNAL(textChanged(const QString&)), SLOT(Ex_Start_IP_change1(const QString&)));
+  connect( Ex_Start_IP_Edit2, SIGNAL(textChanged(const QString&)), SLOT(Ex_Start_IP_change2(const QString&)));
+  connect( Ex_Start_IP_Edit3, SIGNAL(textChanged(const QString&)), SLOT(Ex_Start_IP_change3(const QString&)));
+  connect( Ex_Start_IP_Edit4, SIGNAL(textChanged(const QString&)), SLOT(Ex_Start_IP_change4(const QString&)));
+  connect( Ex_End_IP_Edit1, SIGNAL(textChanged(const QString&)), SLOT(Ex_End_IP_change1(const QString&)));
+  connect( Ex_End_IP_Edit2, SIGNAL(textChanged(const QString&)), SLOT(Ex_End_IP_change2(const QString&)));
+  connect( Ex_End_IP_Edit3, SIGNAL(textChanged(const QString&)), SLOT(Ex_End_IP_change3(const QString&)));
+  connect( Ex_End_IP_Edit4, SIGNAL(textChanged(const QString&)), SLOT(Ex_End_IP_change4(const QString&)));
 
 
 
-  AddButton->setGeometry((widthSize+140),175,buttonSize,AddButton->sizeHint().height());
-  RemoveButton->setGeometry((widthSize+140),205,buttonSize,RemoveButton->sizeHint().height());
+  AddButton->setGeometry((widthSize+142),200,buttonSize,AddButton->sizeHint().height());
+  RemoveButton->setGeometry((widthSize+142),230,buttonSize,RemoveButton->sizeHint().height());
 
   connect( AddButton, SIGNAL(clicked()), SLOT(Add_Click()) );
   connect( RemoveButton, SIGNAL(clicked()), SLOT(Remove_Click()) );
@@ -241,11 +247,11 @@ scopeDialog::scopeDialog (scopeAddresses *sa,QWidget* parent, const char* name)
   if(radioSize < Limited_Radio->sizeHint().width())
     radioSize = Limited_Radio->sizeHint().width();
 
-  daySpinBox = new KNumericSpinBox(LeasesBox);
+  daySpinBox = new QSpinBox(LeasesBox);
   daySpinBox->setRange(0,365);
-  hourSpinBox = new KNumericSpinBox(LeasesBox);
+  hourSpinBox = new QSpinBox(LeasesBox);
   hourSpinBox->setRange(0,24);
-  minSpinBox = new KNumericSpinBox(LeasesBox);
+  minSpinBox = new QSpinBox(LeasesBox);
   minSpinBox->setRange(0,60);
  
   dayLabel = new QLabel(i18n("Day(s)"), LeasesBox);
@@ -283,11 +289,11 @@ scopeDialog::scopeDialog (scopeAddresses *sa,QWidget* parent, const char* name)
   if(radioSize < Limited_Radio2->sizeHint().width())
     radioSize = Limited_Radio2->sizeHint().width();
 
-  daySpinBox2 = new KNumericSpinBox(MaxLeasesBox);
+  daySpinBox2 = new QSpinBox(MaxLeasesBox);
   daySpinBox2->setRange(0,365);
-  hourSpinBox2 = new KNumericSpinBox(MaxLeasesBox);
+  hourSpinBox2 = new QSpinBox(MaxLeasesBox);
   hourSpinBox2->setRange(0,24);
-  minSpinBox2 = new KNumericSpinBox(MaxLeasesBox);
+  minSpinBox2 = new QSpinBox(MaxLeasesBox);
   minSpinBox2->setRange(0,60);
  
   dayLabel2 = new QLabel(i18n("Day(s)"), MaxLeasesBox);
@@ -333,6 +339,7 @@ void scopeDialog::init()
   hourSpinBox2->setValue(0);
   minSpinBox2->setValue(0);
   DomainName_Edit->setText(sac->domainName);
+  Broadcast_Edit->setText(sac->broadcast);
   NameServers_Edit->setText(sac->nameServers);
   NetbiosNameServers_Edit->setText(sac->netbiosNameServers);
   Subnet_Edit1->setText(getIP(0,(const char*)sac->subnet));
@@ -352,17 +359,17 @@ void scopeDialog::init()
       tmpint = sac->leaseDurations;
       while(tmpint-(24*3600) >= 0)
 	{
-	  daySpinBox->setValue((daySpinBox->getValue()+1));
+	  daySpinBox->setValue((daySpinBox->value()+1));
 	  tmpint-=(24*3600);
 	}
       while((tmpint-3600) >= 0)
 	{
-	  hourSpinBox->setValue((hourSpinBox->getValue()+1));
+	  hourSpinBox->setValue((hourSpinBox->value()+1));
 	  tmpint-=3600;
 	}
       while((tmpint-60) >= 0)
 	{
-	  minSpinBox->setValue((minSpinBox->getValue()+1));
+	  minSpinBox->setValue((minSpinBox->value()+1));
 	  tmpint-=60;
 	}
       Limited_Radio->setChecked(true);
@@ -379,17 +386,17 @@ void scopeDialog::init()
       tmpint = sac->maxLeaseDurations;
       while(tmpint-(24*3600) >= 0)
 	{
-	  daySpinBox2->setValue((daySpinBox2->getValue()+1));
+	  daySpinBox2->setValue((daySpinBox2->value()+1));
 	  tmpint-=(24*3600);
 	}
       while((tmpint-3600) >= 0)
 	{
-	  hourSpinBox2->setValue((hourSpinBox2->getValue()+1));
+	  hourSpinBox2->setValue((hourSpinBox2->value()+1));
 	  tmpint-=3600;
 	}
       while((tmpint-60) >= 0)
 	{
-	  minSpinBox2->setValue((minSpinBox2->getValue()+1));
+	  minSpinBox2->setValue((minSpinBox2->value()+1));
 	  tmpint-=60;
 	}
       Limited_Radio2->setChecked(true);
@@ -416,19 +423,20 @@ void scopeDialog::Help_Click()
 void scopeDialog::OK_Click()
 {
   sac->domainName = DomainName_Edit->text();
+  sac->broadcast = Broadcast_Edit->text();
   sac->nameServers = NameServers_Edit->text();
   sac->netbiosNameServers = NetbiosNameServers_Edit->text();
   sac->subnet = putIP(Subnet_Edit1->text(), Subnet_Edit2->text(), Subnet_Edit3->text(), Subnet_Edit4->text());
   sac->subnetMask = putIP(Mask_Edit1->text(), Mask_Edit2->text(), Mask_Edit3->text(), Mask_Edit4->text());
   sac->routers = Routers_Edit->text();
   if(Limited_Radio->isChecked())
-    sac->leaseDurations = daySpinBox->getValue()*24*3600+hourSpinBox->getValue()*3600+minSpinBox->getValue()*60;
+    sac->leaseDurations = daySpinBox->value()*24*3600+hourSpinBox->value()*3600+minSpinBox->value()*60;
   else if(Unlimited_Radio->isChecked())
     sac->leaseDurations = 0;
   else
     sac->leaseDurations = -1;
   if(Limited_Radio2->isChecked())
-    sac->maxLeaseDurations = daySpinBox2->getValue()*24*3600+hourSpinBox2->getValue()*3600+minSpinBox2->getValue()*60;
+    sac->maxLeaseDurations = daySpinBox2->value()*24*3600+hourSpinBox2->value()*3600+minSpinBox2->value()*60;
   else if(Unlimited_Radio2->isChecked())
     sac->maxLeaseDurations = 0;
   else
@@ -488,24 +496,24 @@ void scopeDialog::Remove_Click()
 }
 
 
-void scopeDialog::Subnet_change1(const char * name)
+void scopeDialog::Subnet_change1(const QString& name)
 {
   if (strlen(name) == 3) Subnet_Edit2->setFocus();
 }
  
-void scopeDialog::Subnet_change2(const char * name)
+void scopeDialog::Subnet_change2(const QString& name)
 {
   if (strlen(name) == 3) Subnet_Edit3->setFocus();
   else if (strlen(name) == 0) Subnet_Edit1->setFocus();
 }
 
-void scopeDialog::Subnet_change3(const char * name)
+void scopeDialog::Subnet_change3(const QString& name)
 {
   if (strlen(name) == 3) Subnet_Edit4->setFocus();
   else if (strlen(name) == 0) Subnet_Edit2->setFocus();
 }
 
-void scopeDialog::Subnet_change4(const char * name)
+void scopeDialog::Subnet_change4(const QString& name)
 {
   if (strlen(name) == 0)  Subnet_Edit3->setFocus();
   else if (strlen(name) == 3) 
@@ -561,24 +569,24 @@ void scopeDialog::Subnet_change4(const char * name)
 }
 
 
-void scopeDialog::Ex_Start_IP_change1(const char * name)
+void scopeDialog::Ex_Start_IP_change1(const QString& name)
 {
   if (strlen(name) == 3) Ex_Start_IP_Edit2->setFocus();
 }
  
-void scopeDialog::Ex_Start_IP_change2(const char * name)
+void scopeDialog::Ex_Start_IP_change2(const QString& name)
 {
   if (strlen(name) == 3) Ex_Start_IP_Edit3->setFocus();
   else if (strlen(name) == 0) Ex_Start_IP_Edit1->setFocus();
 }
 
-void scopeDialog::Ex_Start_IP_change3(const char * name)
+void scopeDialog::Ex_Start_IP_change3(const QString& name)
 {
   if (strlen(name) == 3) Ex_Start_IP_Edit4->setFocus();
   else if (strlen(name) == 0) Ex_Start_IP_Edit2->setFocus();
 }
 
-void scopeDialog::Ex_Start_IP_change4(const char * name)
+void scopeDialog::Ex_Start_IP_change4(const QString& name)
 {
   if (strlen(name) == 3) 
     {
@@ -590,24 +598,24 @@ void scopeDialog::Ex_Start_IP_change4(const char * name)
   else if (strlen(name) == 0) Ex_Start_IP_Edit3->setFocus();
 }
 
-void scopeDialog::Ex_End_IP_change1(const char * name)
+void scopeDialog::Ex_End_IP_change1(const QString& name)
 {
   if (strlen(name) == 3) Ex_End_IP_Edit2->setFocus();
 }
  
-void scopeDialog::Ex_End_IP_change2(const char * name)
+void scopeDialog::Ex_End_IP_change2(const QString& name)
 {
   if (strlen(name) == 3) Ex_End_IP_Edit3->setFocus();
   else if (strlen(name) == 0) Ex_End_IP_Edit1->setFocus();
 }
 
-void scopeDialog::Ex_End_IP_change3(const char * name)
+void scopeDialog::Ex_End_IP_change3(const QString& name)
 {
   if (strlen(name) == 3) Ex_End_IP_Edit4->setFocus();
   else if (strlen(name) == 0) Ex_End_IP_Edit2->setFocus();
 }
 
-void scopeDialog::Ex_End_IP_change4(const char * name)
+void scopeDialog::Ex_End_IP_change4(const QString& name)
 {
   if (strlen(name) == 3) AddButton->setFocus();
   else if (strlen(name) == 0) Ex_End_IP_Edit3->setFocus();
